#ifndef CONFIG_OPTIONS_H
#define CONFIG_OPTIONS_H
#define VERSION_MSG "vmd for IRIX5, version 0.97 (Sat May 13 01:51:57 CDT 1995)"
#define CMDLEN 6
#define DEF_VMDHTMLVIEWER "Mosaic"
#define DEF_VMDBABELBIN "/usr/local/bin/babel"
#define DEF_VMDENVVAR "/usr/local/lib/vmd"
#define DEF_VMDTMPDIR "/tmp"
#define INIT_DEFDISPLAY DISPLAY_WIN
#define INIT_DEFTITLE TITLE_ON
#define INIT_DEFHEIGHT 6.0
#define INIT_DEFDIST -2.0
#define VMD_INITFILE ".vmd_init"
#define VMD_STARTUP ".vmdrc"
#define VMD_CMD_PROMPT "vmd > "
#endif
